<?php
/**
 * Required functions for theme backend.
 *
 * @package crucio
 */

/**
 *
 * Helper Functions
 * @since 1.0.0
 * @version 1.0.0
 *
 */

// cs framework missing
if (! function_exists('cs_get_option')) {
   function cs_get_option(){
    return '';
   }
   function cs_get_customize_option(){
    return '';
   }
}

/**
 *
 * Create custom html structure for comments
 *
 */
if ( ! function_exists('crucio_comment' ) ) {
  function crucio_comment( $comment, $args, $depth ) {

    $GLOBALS['comment'] = $comment;

    $reply_class = ( $comment->comment_parent ) ? 'indented' : '';
    switch ( $comment->comment_type ):
      case 'pingback':
      case 'trackback':
        ?>
          <div class="pingback">
            <?php esc_html_e( 'Pingback:', 'crucio' ); ?> <?php comment_author_link(); ?>
            <?php edit_comment_link( esc_html__( '(Edit)', 'crucio' ), '<span class="edit-link">', '</span>' ); ?>
          </div>
        <?php
        break;
      default:
        // generate comments
        ?>
          <li <?php comment_class('ct-part'); ?> id="li-comment-<?php comment_ID(); ?>">
          <div id="comment-<?php comment_ID(); ?>">
            <div class="content">
              <div class="person">
                <?php echo get_avatar( $comment, '43', '', '', array('class'=>'img-circle') ); ?>
                <a href="#" class="author">
                  <?php comment_author(); ?>
                </a>
              <span class="comment-date">
                <?php comment_date( get_option('date_format') );?>
              </span>
              </div>
              <div class="text">
                <?php comment_text(); ?>
              </div>
              <div class="reply-wrapper">
                <?php
                  comment_reply_link(
                    array_merge( $args,
                      array(
                        'reply_text' => esc_html__( 'Reply', 'crucio' ),
                        'after' => '',
                        'depth' => $depth,
                        'max_depth' => $args['max_depth']
                      )
                    )
                  );
                ?>
              </div>
            </div>
          </div>
         
        <?php
        break;
    endswitch;
  }
}

/**
 *
 * Get categories for shortcode.
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if ( ! function_exists('crucio_element_values' ) ) {
  function crucio_element_values() {

    $args = array(
      'type'     => 'post',
      'taxonomy' => 'category'
    ); 

    $categories = get_categories( $args );
    $list = array();

    foreach ( $categories as $category ) {
      $list[$category->name] = $category->term_id;
    }
    return $list;
  }
}

/*
 * Change exerpt end. 
 */
if ( ! function_exists('crucio_excerpt_more' ) ) {
  function crucio_excerpt_more( $more ) {
    return '...';
  }
}
add_filter('excerpt_more', 'crucio_excerpt_more');


if ( ! function_exists('crucio_wp_link_pages' ) ) {
  function crucio_wp_link_pages() {
    get_post_format();
  }
}

/**
 *
 * Get categories for shortcode.
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if ( ! function_exists('crucio_categories' ) ) {
  function crucio_categories() {

    $args = array(
      'type'     => 'post',
      'taxonomy' => 'category'
    ); 

    $categories = get_categories( $args );
    $list = array();

    foreach ( $categories as $category ) {
      $list[$category->name] = $category->slug;
    }
    return $list;
  }
}

// Change excerpt length.
if ( ! function_exists('crucio_excerpt_length' ) ) {
  function crucio_excerpt_length( $length ) {
    return 22;
  }
}
add_filter( 'excerpt_length', 'crucio_excerpt_length', 999 );

// Custom row styles for onepage site type+-.
if ( ! function_exists('crucio_dynamic_css' ) ) {
  function crucio_dynamic_css() {
    require_once get_template_directory() . '/assets/css/custom.css.php';
    wp_die();
  }
}
add_action( 'wp_ajax_nopriv_crucio_dynamic_css', 'crucio_dynamic_css' );
add_action( 'wp_ajax_crucio_dynamic_css', 'crucio_dynamic_css' );

// Remove role attribute from search form.
if ( ! function_exists('crucio_valid_search_form' ) ) {
  function crucio_valid_search_form ($form) {
    return str_replace('role="search" ', '', $form);
  }
}
add_filter('get_search_form', 'crucio_valid_search_form');